==> single-spa-customer-app-0.0.16.tgz: package/src/app/app.module.ts <==
import { BrowserModule } from "@angular/platform-browser";
import { NgModule } from "@angular/core";

import { AppRoutingModule } from "./app-routing.module";
import { AppComponent } from "./app.component";

import { APP_BASE_HREF } from "@angular/common";
import { ListComponent } from "./list/list.component";
import { EmptyRouteComponent } from "./empty-route/empty-route.component";
import { FormsModule } from "@angular/forms";
import { AddUpdateUserComponent } from './add-update-user/add-update-user.component';
import { EquipmentCategoryListComponent } from './equipment-category-list/equipment-category-list.component';
import { EquipmentListComponent } from './equipment-list/equipment-list.component';
import { MonitoringStationListComponent } from './monitoring-station-list/monitoring-station-list.component';
import { MapComponent } from "./map-dialog/map/map.component";
import { GoogleMapsModule } from "@angular/google-maps";
import { AgmCoreModule } from '@agm/core';
import { MatDialogModule } from "@angular/material";
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
@NgModule({
  declarations: [
    AppComponent,
    ListComponent,
    EmptyRouteComponent,
    AddUpdateUserComponent,
    EquipmentCategoryListComponent,
    EquipmentListComponent,
    MonitoringStationListComponent,
    MapComponent,
  ],
  imports: [BrowserModule,
     AppRoutingModule,
      FormsModule,
      AgmCoreModule.forRoot({
        apiKey: 'AIzaSyDqee8a0uU3XzR6YS7yxYPRMplU92F_U2M',
        libraries: ['places']
      }),
      GoogleMapsModule,
      MatDialogModule,
      BrowserAnimationsModule
    ],
  providers: [{ provide: APP_BASE_HREF, useValue: "/" }],
  bootstrap: [AppComponent],
  entryComponents: [MapComponent]
})
export class AppModule {}

==> single-spa-customer-app-0.0.28.tgz: package/src/app/app.module.ts <==
import { BrowserModule } from "@angular/platform-browser";
import { NgModule } from "@angular/core";

import { AppRoutingModule } from "./app-routing.module";
import { AppComponent } from "./app.component";

import { APP_BASE_HREF } from "@angular/common";
import { ListComponent } from "./list/list.component";
import { EmptyRouteComponent } from "./empty-route/empty-route.component";
import { FormsModule } from "@angular/forms";
import { AddUpdateUserComponent } from './add-update-user/add-update-user.component';
import { EquipmentCategoryListComponent } from './equipment-category-list/equipment-category-list.component';
import { EquipmentListComponent } from './equipment-list/equipment-list.component';
import { MonitoringStationListComponent } from './monitoring-station-list/monitoring-station-list.component';
import { AddUpdateMonitoringStationComponent } from './add-update-monitoring-station/add-update-monitoring-station.component';
import { AgmCoreModule } from '@agm/core';
@NgModule({
  declarations: [
    AppComponent,
    ListComponent,
    EmptyRouteComponent,
    AddUpdateUserComponent,
    EquipmentCategoryListComponent,
    EquipmentListComponent,
    MonitoringStationListComponent,
    AddUpdateMonitoringStationComponent,
  ],
  imports: [BrowserModule,
     AppRoutingModule,
      FormsModule,
      AgmCoreModule.forRoot({
        apiKey: 'AIzaSyBtNtYzlXXr0UWwv9A5u8Dy7j-_rQY1Qd4',
        libraries: ['places']
      })
    ],
    
  providers: [{ provide: APP_BASE_HREF, useValue: "/" }],
  bootstrap: [AppComponent],
})
export class AppModule {}
